@@ -151,7 +151,11 @@ def create_daily_dist_dict_for_month(month_timestamp: pd.Timestamp, weekly_distr
     start_date = month_timestamp.replace(day=1)
     end_date = start_date + relativedelta(months=1) + relativedelta(days=-1)
     date_range = pd.date_range(start=start_date, end=end_date, freq="W-MON")
-    date_range = [date for date in date_range if date.month == month_timestamp.month]
+    # Check if the month includes days from previous ISO weeks and include them if so
+    if date_range[0] > start_date:
+        week_before_start_date = start_date + relativedelta(days=-7)
+        additional_date_range = pd.date_range(week_before_start_date, start_date, freq="W-MON")
+        date_range = date_range.union(additional_date_range)
 
     # Apply distribution, create dict of weeks and their relative weights
     weekly_dist_dict = {}
@@ -184,7 +188,7 @@ def create_daily_dist_dict_for_month(month_timestamp: pd.Timestamp, weekly_distr
         # Create a distribution dictionary by multiplying the week's weight with the weekdays weight for each day
         weekday_dist = {
             week_dates[weekday_index].date(): weekday_distribution[weekday_index] * row[WEIGHT_LABEL]
-            for weekday_index in weekday_distribution
+            for weekday_index in weekday_distribution if week_dates[weekday_index].date().month == month_timestamp.month
         }
         daily_dist_dict.update(weekday_dist)
 
