@@ -495,6 +495,20 @@ CURVES = {
                 "anchor_type": "month_of_year",
                 "anchor_point": 12.0
             }
+        ],
+        "kv_standard": [
+            {'anchor_type': 'month_of_year', 'anchor_point': 1.0, 'anchor_value': 7.8},
+            {'anchor_type': 'month_of_year', 'anchor_point': 2.0, 'anchor_value': 15.11},
+            {'anchor_type': 'month_of_year', 'anchor_point': 3.0, 'anchor_value': 23.66},
+            {'anchor_type': 'month_of_year', 'anchor_point': 4.0, 'anchor_value': 32.99},
+            {'anchor_type': 'month_of_year', 'anchor_point': 5.0, 'anchor_value': 42.14},
+            {'anchor_type': 'month_of_year', 'anchor_point': 6.0, 'anchor_value': 50.89},
+            {'anchor_type': 'month_of_year', 'anchor_point': 7.0, 'anchor_value': 59.74},
+            {'anchor_type': 'month_of_year', 'anchor_point': 8.0, 'anchor_value': 67.79},
+            {'anchor_type': 'month_of_year', 'anchor_point': 9.0, 'anchor_value': 75.74},
+            {'anchor_type': 'month_of_year', 'anchor_point': 10.0, 'anchor_value': 83.74},
+            {'anchor_type': 'month_of_year', 'anchor_point': 11.0, 'anchor_value': 91.95},
+            {'anchor_type': 'month_of_year', 'anchor_point': 12.0, 'anchor_value': 100.0}
         ]
     },
     "week": {
@@ -2331,7 +2345,60 @@ CURVES = {
                 "anchor_type": "week_of_year",
                 "anchor_point": 52.0
             }
-        ]
+        ],
+        "kv_standard": [
+            {'anchor_type': 'week_of_year', 'anchor_point': 1.0, 'anchor_value': 1.7},
+            {'anchor_type': 'week_of_year', 'anchor_point': 2.0, 'anchor_value': 3.47},
+            {'anchor_type': 'week_of_year', 'anchor_point': 3.0, 'anchor_value': 5.28},
+            {'anchor_type': 'week_of_year', 'anchor_point': 4.0, 'anchor_value': 7.07},
+            {'anchor_type': 'week_of_year', 'anchor_point': 5.0, 'anchor_value': 8.84},
+            {'anchor_type': 'week_of_year', 'anchor_point': 6.0, 'anchor_value': 10.58},
+            {'anchor_type': 'week_of_year', 'anchor_point': 7.0, 'anchor_value': 12.29},
+            {'anchor_type': 'week_of_year', 'anchor_point': 8.0, 'anchor_value': 14.04},
+            {'anchor_type': 'week_of_year', 'anchor_point': 9.0, 'anchor_value': 15.84},
+            {'anchor_type': 'week_of_year', 'anchor_point': 10.0, 'anchor_value': 17.68},
+            {'anchor_type': 'week_of_year', 'anchor_point': 11.0, 'anchor_value': 19.55},
+            {'anchor_type': 'week_of_year', 'anchor_point': 12.0, 'anchor_value': 21.45},
+            {'anchor_type': 'week_of_year', 'anchor_point': 13.0, 'anchor_value': 23.4},
+            {'anchor_type': 'week_of_year', 'anchor_point': 14.0, 'anchor_value': 25.59},
+            {'anchor_type': 'week_of_year', 'anchor_point': 15.0, 'anchor_value': 28.01},
+            {'anchor_type': 'week_of_year', 'anchor_point': 16.0, 'anchor_value': 30.52},
+            {'anchor_type': 'week_of_year', 'anchor_point': 17.0, 'anchor_value': 32.98},
+            {'anchor_type': 'week_of_year', 'anchor_point': 18.0, 'anchor_value': 35.41},
+            {'anchor_type': 'week_of_year', 'anchor_point': 19.0, 'anchor_value': 37.79},
+            {'anchor_type': 'week_of_year', 'anchor_point': 20.0, 'anchor_value': 40.13},
+            {'anchor_type': 'week_of_year', 'anchor_point': 21.0, 'anchor_value': 42.41},
+            {'anchor_type': 'week_of_year', 'anchor_point': 22.0, 'anchor_value': 44.4},
+            {'anchor_type': 'week_of_year', 'anchor_point': 23.0, 'anchor_value': 46.37},
+            {'anchor_type': 'week_of_year', 'anchor_point': 24.0, 'anchor_value': 48.33},
+            {'anchor_type': 'week_of_year', 'anchor_point': 25.0, 'anchor_value': 50.25},
+            {'anchor_type': 'week_of_year', 'anchor_point': 26.0, 'anchor_value': 52.13},
+            {'anchor_type': 'week_of_year', 'anchor_point': 27.0, 'anchor_value': 54.06},
+            {'anchor_type': 'week_of_year', 'anchor_point': 28.0, 'anchor_value': 55.97},
+            {'anchor_type': 'week_of_year', 'anchor_point': 29.0, 'anchor_value': 57.87},
+            {'anchor_type': 'week_of_year', 'anchor_point': 30.0, 'anchor_value': 59.76},
+            {'anchor_type': 'week_of_year', 'anchor_point': 31.0, 'anchor_value': 61.62},
+            {'anchor_type': 'week_of_year', 'anchor_point': 32.0, 'anchor_value': 63.45},
+            {'anchor_type': 'week_of_year', 'anchor_point': 33.0, 'anchor_value': 65.25},
+            {'anchor_type': 'week_of_year', 'anchor_point': 34.0, 'anchor_value': 67.01},
+            {'anchor_type': 'week_of_year', 'anchor_point': 35.0, 'anchor_value': 68.81},
+            {'anchor_type': 'week_of_year', 'anchor_point': 36.0, 'anchor_value': 70.6},
+            {'anchor_type': 'week_of_year', 'anchor_point': 37.0, 'anchor_value': 72.34},
+            {'anchor_type': 'week_of_year', 'anchor_point': 38.0, 'anchor_value': 74.13},
+            {'anchor_type': 'week_of_year', 'anchor_point': 39.0, 'anchor_value': 75.95},
+            {'anchor_type': 'week_of_year', 'anchor_point': 40.0, 'anchor_value': 77.8},
+            {'anchor_type': 'week_of_year', 'anchor_point': 41.0, 'anchor_value': 79.66},
+            {'anchor_type': 'week_of_year', 'anchor_point': 42.0, 'anchor_value': 81.49},
+            {'anchor_type': 'week_of_year', 'anchor_point': 43.0, 'anchor_value': 83.3},
+            {'anchor_type': 'week_of_year', 'anchor_point': 44.0, 'anchor_value': 85.09},
+            {'anchor_type': 'week_of_year', 'anchor_point': 45.0, 'anchor_value': 86.94},
+            {'anchor_type': 'week_of_year', 'anchor_point': 46.0, 'anchor_value': 88.86},
+            {'anchor_type': 'week_of_year', 'anchor_point': 47.0, 'anchor_value': 90.81},
+            {'anchor_type': 'week_of_year', 'anchor_point': 48.0, 'anchor_value': 92.67},
+            {'anchor_type': 'week_of_year', 'anchor_point': 49.0, 'anchor_value': 94.52},
+            {'anchor_type': 'week_of_year', 'anchor_point': 50.0, 'anchor_value': 96.4},
+            {'anchor_type': 'week_of_year', 'anchor_point': 51.0, 'anchor_value': 98.23},
+            {'anchor_type': 'week_of_year', 'anchor_point': 52.0, 'anchor_value': 100.0}]
     }
 }
 CONFIGS = {
