@@ -250,8 +250,24 @@ class SampleCurve:
             for feature in self.curve_features:
                 feature.add_to_curve(year, year_df)
 
-            # Fill in intermediary values with cumulative sum
-            year_df = year_df.interpolate()
+            # Reduce cumulative sum to individual period values
+            year_df["temp"] = year_df[self.value_column_name].diff().fillna(
+                year_df[self.value_column_name])
+
+            # Fill in intermediary values with average of the values between them
+            missing_mask = year_df.value.isnull()
+            if sum(missing_mask) > 0:
+                average_mask = year_df.week_number.isin([41, 44])
+                fill_in_value = year_df[average_mask].temp.mean()
+                fill_mask = year_df.week_number.isin([42, 43])
+                year_df.loc[fill_mask, "temp"] = fill_in_value
+                year_df["pct_of_total"] = year_df["temp"] / year_df["temp"].sum()
+
+                overshoot = year_df.temp.sum() - 100
+                year_df["adjustment"] = overshoot * year_df["pct_of_total"]
+                year_df["temp"] = year_df["temp"] - year_df["adjustment"]
+                year_df["value"] = year_df.temp.cumsum()
+                year_df = year_df.drop(columns=["temp", "pct_of_total", "adjustment"])
 
             # Reduce cumulative sum to individual period values
             year_df[self.value_column_name] = year_df[self.value_column_name].diff().fillna(
